@@ -1,10 +1,10 @@
 !
-!  This file is part of MUMPS 5.1.1, released
-!  on Mon Mar 20 14:34:33 UTC 2017
+!  This file is part of MUMPS 5.2.1, released
+!  on Fri Jun 14 14:46:05 UTC 2019
 !
 !
-!  Copyright 1991-2017 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
-!  University of Bordeaux.
+!  Copyright 1991-2019 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
+!  Mumps Technologies, University of Bordeaux.
 !
 !  This version of MUMPS is provided to you free of charge. It is
 !  released under the CeCILL-C license:
